import { getChartCategory, getChartSeries, getPropertyHierarchy, getPropertyMeasure, getPropertyName, mergeOptions } from '@metad/ocap-core';
import { measuresToSeriesComponents, serializeSeriesComponent } from './cartesian';
export function cartesian3d(data, chartAnnotation, entityType, settings, options, type) {
    const cartesianCoordinate = cartesianCoordinate3d(data.data, chartAnnotation, entityType, settings, options);
    const echartsOptions = {
        dataset: [],
        grid3D: [],
        xAxis3D: [],
        yAxis3D: [],
        zAxis3D: [],
        series: [],
        visualMap: []
    };
    [cartesianCoordinate].forEach((cartesianCoordinate) => {
        echartsOptions.grid3D.push(cartesianCoordinate.grid3D);
        echartsOptions.xAxis3D.push(cartesianCoordinate.xAxis3D);
        echartsOptions.yAxis3D.push(cartesianCoordinate.yAxis3D);
        echartsOptions.zAxis3D.push(cartesianCoordinate.zAxis3D);
        echartsOptions.visualMap.push(...cartesianCoordinate.visualMap);
        cartesianCoordinate.datasets.forEach(({ dataset, series }) => {
            echartsOptions.dataset.push(dataset);
            series.forEach((series) => {
                echartsOptions.series.push({
                    ...series,
                    datasetIndex: echartsOptions.dataset.length - 1,
                    type: series.type ?? type
                });
            });
        });
    });
    return echartsOptions;
}
// 单个笛卡尔坐标系
export function cartesianCoordinate3d(data, chartAnnotation, entityType, settings, options) {
    const category = getChartCategory(chartAnnotation);
    const category2 = getChartSeries(chartAnnotation);
    // const tooltips = chartAnnotation.measures.filter(({ role }) => role === ChartMeasureRoleType.Tooltip)
    const datasets = [
        {
            dataset: {
                source: data,
                dimensions: [
                    ...chartAnnotation.dimensions.map(getPropertyName),
                    ...chartAnnotation.measures.map(getPropertyMeasure)
                ]
            },
            seriesComponents: measuresToSeriesComponents(chartAnnotation.measures, data, entityType, settings)
        }
    ];
    const grid3dOptions = {
        grid3D: mergeOptions({
            top: 0,
            right: 0,
            bottom: 0,
            left: 0,
            containLabel: true
        }, options?.grid3D),
        xAxis3D: {
            type: 'category'
        },
        yAxis3D: {
            type: 'category'
        },
        zAxis3D: {
            type: 'value'
        },
        visualMap: [],
        datasets: []
    };
    datasets.forEach(({ dataset, seriesComponents }) => {
        grid3dOptions.datasets.push({
            dataset,
            series: seriesComponents.map((seriesComponent) => {
                const { series, visualMaps } = serializeSeriesComponent(dataset, seriesComponent, entityType, 'z', settings, options);
                grid3dOptions.visualMap.push(...visualMaps);
                series.encode = {
                    x: getPropertyHierarchy(category),
                    y: getPropertyHierarchy(category2),
                    z: seriesComponent.measure
                };
                return mergeOptions(series, options?.seriesStyle);
            })
        });
    });
    return grid3dOptions;
}
//# sourceMappingURL=cartesian3d.js.map