import { ChartDimensionRoleType, getChartCategory, getChartCategory2, getEntityHierarchy, getEntityLevel, getPropertyCaption, mergeOptions, omitBlank } from '@metad/ocap-core';
import format from 'date-fns/format';
import parse from 'date-fns/parse';
import { cloneDeep } from 'lodash-es';
import { coordinates, gatherCoordinates } from './coordinates';
export function themeRiver(data, chartAnnotation, entityType, settings, options) {
    // 智能补全信息
    const index = chartAnnotation.dimensions.findIndex((item) => item.role === ChartDimensionRoleType.Category2);
    if (index === -1) {
        chartAnnotation = cloneDeep(chartAnnotation);
        const dimension = chartAnnotation.dimensions.slice(1).find((item) => !item.role);
        if (dimension) {
            dimension.role = ChartDimensionRoleType.Category2;
        }
    }
    const coordinateDatas = coordinates(data, chartAnnotation, entityType, settings, options, 'grid', themeRiverCoordinate);
    return gatherCoordinates(coordinateDatas, 'themeRiver', options);
}
/**
 * 未来支持:
 *  1. 基于维度成员的主题河
 *  2. 基于不同度量的主题河
 *
 * @param data
 * @param chartAnnotation
 * @param entityType
 * @param settings
 * @param options
 * @returns
 */
export function themeRiverCoordinate(data, chartAnnotation, entityType, settings, options) {
    const category = getChartCategory(chartAnnotation);
    // const categoryProperty = getEntityProperty(entityType, category)
    const categoryCaption = getPropertyCaption(getEntityHierarchy(entityType, category));
    const category2 = getChartCategory2(chartAnnotation);
    if (!category2) {
        throw new Error(`至少两个维度`);
    }
    const category2Hierarchy = getEntityHierarchy(entityType, category2);
    const category2Caption = getPropertyCaption(category2Hierarchy);
    const measure = chartAnnotation.measures[0];
    const categoryLevelProperty = getEntityLevel(entityType, category);
    console.log(categoryLevelProperty);
    const formatter = categoryLevelProperty.semantics?.formatter || 'yyyyMMdd';
    const coordinateOptions = {
        type: 'SingleAxis',
        name: '',
        datasets: [
            {
                series: [
                    {
                        data: data.map((item) => [
                            format(parse(item[categoryCaption], formatter, new Date()), 'yyyy/MM/dd'),
                            item[measure.measure],
                            item[category2Caption]
                        ])
                    }
                ]
            }
        ],
        grid: mergeOptions({}, options?.grid),
        singleAxis: [
            mergeOptions({
                type: 'time'
            }, options?.singleAxis)
        ],
        visualMap: [],
        tooltip: [],
        legend: []
    };
    if (options?.legend) {
        coordinateOptions.legend.push(omitBlank(options.legend));
    }
    if (options?.tooltip) {
        coordinateOptions.tooltip.push(mergeOptions({
            valueFormatter: (value) => value.toFixed(2)
        }, options.tooltip));
    }
    return coordinateOptions;
}
//# sourceMappingURL=themeRiver.js.map