import { ChartMeasure, ChartOptions, IMember, Property } from "@metad/ocap-core";
export declare enum AxisEnum {
    x = "xAxis",
    y = "yAxis",
    xAxis = "x",
    yAxis = "y",
    radius = "radiusAxis",
    angle = "angleAxis",
    radiusAxis = "radius",
    angleAxis = "angle",
    singleAxis = "singleAxis"
}
export interface SeriesComponentType extends Partial<ChartMeasure> {
    member?: IMember;
    id?: string;
    name: string;
    caption?: string;
    seriesType?: string;
    seriesStack?: string;
    noDisplay?: boolean;
    property?: Property;
    dataMin?: number;
    dataMax?: number;
    dataSize?: number;
    categoryAxisIndex?: number;
    valueAxisIndex?: number;
    measures?: Array<string>;
    datasetIndex?: number;
    seriesLayoutBy?: string;
    tooltip?: string[];
    sizeMeasure?: ChartMeasure;
    lightnessMeasure?: ChartMeasure;
}
export interface EChartsOptions extends ChartOptions {
    /**
     * https://echarts.apache.org/en/option.html#grid
     */
    grid?: any;
    grid3D?: any;
    geo?: any;
    /**
     * https://echarts.apache.org/en/option.html#legend
     */
    legend?: any;
    /**
     * https://echarts.apache.org/en/option.html#dataZoom
     */
    dataZoom?: any;
    /**
     * https://echarts.apache.org/en/option.html#visualMap
     */
    visualMaps?: IVisualMap[];
    /**
     * https://echarts.apache.org/en/option.html#tooltip
     */
    tooltip?: ITooltip;
    categoryAxis?: any;
    /**
     * https://echarts.apache.org/en/option.html#yAxis
     */
    valueAxis?: any;
    singleAxis?: any;
    calendar?: any;
    /**
     * https://echarts.apache.org/en/option.html#series
     */
    seriesStyle?: any;
    colors?: {
        /**
         * https://echarts.apache.org/en/option.html#color
         */
        color: string[];
    };
    /**
     * https://echarts.apache.org/en/option.html#aria
     */
    aria?: any;
    polar?: any;
    animation?: boolean;
    animationThreshold?: number;
    animationDuration?: number | ((idx: number) => number);
    animationEasing?: string;
    animationDelay?: number | ((idx: number) => number);
    animationDurationUpdate?: number | ((idx: number) => number);
    animationEasingUpdate?: string;
    animationDelayUpdate?: number | ((idx: number) => number);
    hoverLayerThreshold?: number;
    useUTC?: boolean;
}
export declare const FORMAT_LOCALE_DATA: {
    en: {
        lang: string;
        shortNumberFactor: number;
        shortNumberUnits: string;
    };
    'zh-Hans': {
        lang: string;
        shortNumberFactor: number;
        shortNumberUnits: string;
    };
};
export interface ICoordinate {
    type: '' | 'Cartesian2d' | 'SingleAxis' | 'Polar' | 'Pie' | 'Calendar';
    name: string;
    datasets: IDataset[];
    grid?: any;
    title?: any;
    visualMap?: any;
    tooltip?: any;
    legend?: any;
}
export interface ICoordinateCartesian2d extends ICoordinate {
    xAxis?: any;
    yAxis?: any;
}
export interface ICoordinateSingleAxis extends ICoordinate {
    singleAxis: any;
}
export interface ICoordinatePolar extends ICoordinate {
    polar: any;
    radiusAxis: any;
    angleAxis: any;
}
export interface ICoordinateCalendar extends ICoordinate {
    calendar: any;
}
export interface ITooltip {
    shortNumber?: boolean;
    appendToBody?: boolean;
    trigger?: 'axis' | 'item';
    formatter?: (e: any) => void;
}
export interface IDataset {
    series?: any[];
    seriesComponents?: SeriesComponentType[];
    tooltip?: any;
    dataset?: {
        id?: string;
        source: any;
        measure?: string;
        dimensions?: string[];
        categories?: any[];
        series?: any[];
    };
}
export interface IVisualMap {
    type: 'piecewise' | 'continuous';
    show?: boolean;
    inRange: any;
    text?: [string?, string?];
    min?: number;
    max?: number;
    dimension?: string | number;
}
export declare const isCoordinateCartesian2d: (toBe: any) => toBe is ICoordinateCartesian2d;
export declare const isCoordinateSingleAxis: (toBe: any) => toBe is ICoordinateSingleAxis;
export declare const isCoordinatePolar: (toBe: any) => toBe is ICoordinatePolar;
export declare const isCoordinateCalendar: (toBe: any) => toBe is ICoordinateCalendar;
