import { maxBy, minBy, range } from 'lodash-es';
import { getChromaticScale } from './chromatics';
export function getColorLightnessVisualMap(measure, property, dataset, visualMaps) {
    const _dataset = Array.isArray(dataset) ? dataset[0] : dataset;
    const dataMin = minBy(_dataset.source, measure.measure)?.[measure.measure];
    const dataMax = maxBy(_dataset.source, measure.measure)?.[measure.measure];
    // const visualMap = visualMaps?.find((item) => item.type === 'continuous') ?? {}
    return {
        dimension: _dataset.dimensions ? _dataset.dimensions.indexOf(measure.measure) : measure.measure,
        min: dataMin,
        max: dataMax,
        // itemHeight: 120,
        text: [property.label || property.name]
        // textGap: 30,
        // inRange: {
        //   colorLightness: [0.9, 0.5]
        // },
        // outOfRange: {
        //   color: ['rgba(255,255,255,0.4)']
        // },
        // controller: {
        //   inRange: {
        //     color: ['#c23531']
        //   },
        //   outOfRange: {
        //     color: ['#999']
        //   }
        // },
        // ...visualMap
    };
}
/**
 * 将 Measure 的 Palette 转换成 ECharts VisualMap 组件
 *
 * @param palette
 * @param measure
 * @param data
 * @returns
 */
export function getMeasurePaletteVisualMap(palette, measure, data) {
    if (!palette) {
        return null;
    }
    const dataMin = measure.dataMin ?? minBy(data, measure.measure)?.[measure.measure];
    const dataMax = measure.dataMax ?? maxBy(data, measure.measure)?.[measure.measure];
    const domain = measure.domain || [dataMin, dataMax];
    const inRange = { color: [] };
    if (palette?.name) {
        const colorFun = getChromaticScale(palette.name, [0, measure.dataSize - 1], palette.reverse);
        inRange.color = range(measure.dataSize).map((i) => colorFun(i));
    }
    else if (palette?.color) {
        inRange.color = palette.color;
    }
    return {
        show: false,
        type: 'continuous',
        text: [measure.property.caption || measure.property.label || measure.property.name],
        min: domain[0],
        max: domain[1],
        inRange
    };
}
//# sourceMappingURL=visualMap.js.map